<template>
  <basic-container>
    <avue-crud
      ref="userCrud"
      :before-open="beforeOpen"
      :data="tableData"
      :option="option"
      :page.sync="page"
      :table-loading="tableLoading"
      @on-load="getTableList"
      @refresh-change="handleRefresh"
      @search-change="handleSearch"
      @search-reset="handleReset"
      @size-change="sizeChange"
      @current-change="currentChange"
      @selection-change="selectChange"
      @row-click="rowClickHandler"
      @row-save="rowSaveHandler"
      @row-update="rowUpdateHandler"
    >
      <!-- 部门头部搜索插槽  -->
      <template slot-scope="{disabled,size}" slot="pkDepartmentNameSearch">
        <div style="display: flex;gap: 5px">
          <el-select v-model="departSearchValue" clearable placeholder="请选择部门">
            <el-option :label="departSearchObj.name" :value="departSearchObj.oid"></el-option>
          </el-select>
          <el-button size="small" type="success" @click="dialogDepartSearchHandler">选择部门</el-button>
        </div>
      </template>

      <template #menu="{row,index,size}">
        <el-button icon="el-icon-edit" size="small" type="text" @click.stop="rowEditHandler(row,index)">导出</el-button>
      </template>

      <template slot="menuLeft" slot-scope="scope">
        <el-button icon="el-icon-delete" plain size="small" type="danger" @click="allDelHandler">导出</el-button>
      </template>
    </avue-crud>
  </basic-container>
</template>

<script>
import basicOption from "@/util/basic-option";
import {getLogListByContion} from "@/api/log/logBasic";
import func from "@/util/func";

export default {
name: "index",
  data: function () {
    return {
      tableLoading: false,
      tableData: [],
      option: {
        ...basicOption,
        editBtn: false,
        delBtn: false,
        calcHeight: -60,
        column: [
          {
            label: '用户名',
            prop: 'truename',
            search:true,
            sortable:true,
          }, {
            label: '姓名',
            prop: 'username',
            search:true,
            sortable:true,
          },{
            label: '用户IP',
            prop: 'userIp',
            search:true,
            sortable:true,
          },{
            label: '模块',
            prop: 'moduleName',
            search:true,
            sortable:true,
          },{
            label: '操作',
            prop: 'type',
            search:true,
            sortable:true,
          },{
            label: '时间',
            prop: 'startDate',
            search:true,
            sortable:true,
          },{
            label: '操作结果',
            prop: 'result',
            search:true,
            sortable:true,
          },{
            label: '描述',
            prop: 'startDate',
            search:true,
            sortable:true,
          },
        ]
      },
      page: {
        currentPage: 1,
        pageSize: 50,
        total: 0,
        pageSizes: [10, 30, 50, 100],
      },
      searchParams: {}
    }
  },
  methods: {
    // 表格请求
    getTableList() {
      this.tableLoading = true;
      getLogListByContion(this.page.currentPage, this.page.pageSize, this.searchParams).then(res => {
        const data = res.data.data;
        this.tableData = data;
        this.page.total = res.data.total;
        this.tableLoading = false;
      })
    },

    // 搜索查询
    handleSearch(params, done) {
      this.searchParams = {};
      if(this.departSearchObj && this.departSearchValue){
        this.searchParams['conditionMap["pkDepartment"]'] = this.departSearchValue;
      }

      if (!func.isEmptyObject(params)) {
        for (let key in params) {
          if (params.hasOwnProperty(key)) {
            // 判断如果 key 是 'pkPersonName'，则改为 'pkPerson' 分别为显示值和保存值
            let newKey = key === 'pkPersonName' ? 'pkPerson' : key;
            this.searchParams[`conditionMap["${newKey}"]`] = params[key];
          }
        }
      }

      if (func.isEmptyObject(params) && !this.departSearchValue) {
        this.searchParams = {};
      }

      this.getTableList();
      done();
    },

    // 重置搜索条件
    handleReset() {
      this.departSearchObj = {};
      this.departSearchValue = "";
      this.searchParams = {};
      this.getTableList();
    },

    // 条数
    sizeChange(val) {
      this.page.pageSize = val;
    },

    // 页码
    currentChange(val) {
      this.page.currentPage = val;
    },
  }
}
</script>

<style scoped>

</style>
